@@ -50,6 +50,9 @@ Usage (String-based API - Backward Compatible):
     result = await dominus("secrets.get", key="DB_URL")
 """
 import os
+import httpx
+import base64
+import json
 from typing import Optional, Any, Dict, List
 
 # Module-level state
@@ -326,9 +329,106 @@ class Dominus:
         self.open = OpenNamespace(_execute_command)
         self.health = HealthNamespace(_execute_command)
 
+        # Initialize portal namespace (needs client reference for _request)
+        from .namespaces.portal import PortalNamespace
+        self.portal = PortalNamespace(self)
+
         # Cache for JWT public key
         self._public_key_cache = None
 
+    # ========================================
+    # INTERNAL REQUEST METHOD (for user JWT)
+    # ========================================
+
+    async def _request(
+        self,
+        endpoint: str,
+        method: str = "POST",
+        body: Optional[Dict[str, Any]] = None,
+        user_token: Optional[str] = None
+    ) -> Dict[str, Any]:
+        """
+        Make an HTTP request to the orchestrator.
+
+        If user_token is provided, uses that JWT directly (for user-authenticated requests).
+        Otherwise, uses the service token flow (PSK -> JWT).
+
+        Args:
+            endpoint: API endpoint path (e.g., "/api/portal/auth/me")
+            method: HTTP method (GET, POST, PUT, DELETE)
+            body: Request body (will be base64-encoded)
+            user_token: Optional user JWT for user-authenticated requests
+
+        Returns:
+            Response data dict
+        """
+        global _VALIDATED
+
+        # Base64 helpers
+        def _b64_encode(d: dict) -> str:
+            return base64.b64encode(json.dumps(d).encode()).decode()
+
+        def _b64_decode(s: str) -> dict:
+            return json.loads(base64.b64decode(s.encode('utf-8')).decode('utf-8'))
+
+        # Determine which JWT to use
+        if user_token:
+            # Use the provided user JWT directly (no validation needed - orchestrator validates it)
+            jwt = user_token
+        else:
+            # Use service token flow - validate first if needed
+            if _VALIDATION_ERROR:
+                raise RuntimeError(_VALIDATION_ERROR)
+
+            if not _VALIDATED:
+                from .helpers.core import verify_token_format, health_check_all
+
+                # Basic token format check
+                verify_token_format(_TOKEN)
+
+                # Health check to warm up the server
+                result = await health_check_all(_BASE_URL)
+                if result["status"] != "healthy" and result["status"] != "ok":
+                    raise RuntimeError(f"Services unhealthy: {result['message']}")
+
+                _VALIDATED = True
+
+            # Get service JWT
+            from .helpers.core import _ensure_valid_jwt
+            jwt = await _ensure_valid_jwt(_TOKEN, _BASE_URL)
+
+        # Prepare request
+        headers = {
+            "Authorization": f"Bearer {jwt}",
+            "Content-Type": "text/plain"
+        }
+
+        # Prepare body
+        body_b64 = _b64_encode(body or {})
+
+        # Make request
+        async with httpx.AsyncClient(base_url=_BASE_URL, headers=headers, timeout=30.0) as client:
+            if method == "GET":
+                response = await client.get(endpoint)
+            elif method == "DELETE":
+                response = await client.delete(endpoint)
+            elif method == "PUT":
+                response = await client.put(endpoint, content=body_b64)
+            else:
+                response = await client.post(endpoint, content=body_b64)
+
+        response.raise_for_status()
+
+        # Decode base64 response
+        result = _b64_decode(response.text)
+
+        # Check for success
+        if not result.get("success"):
+            error_msg = result.get("error", "Unknown error")
+            raise RuntimeError(f"Request error: {error_msg}")
+
+        return result.get("data", {})
+
     # ========================================
     # SECRETS (root level)
     # ========================================
